@@ -1,8 +1,10 @@
 import asyncio
+from abc import ABC
 from typing import Any, Dict, Optional
 
 from pydantic import validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 
 POST_PATH = "/users/{user_uuid}/creditreport"
@@ -12,7 +14,7 @@ GET_PATH = "/users/{user_uuid}/creditreport/{report_id}"
 CreditReport = Dict[str, Any]
 
 
-class BaseCreditReportResource:
+class BaseCreditReportResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
@@ -53,10 +55,12 @@ class BaseCreditReportResource:
 
 
 class AsyncCreditReportResource(BaseCreditReportResource):
+    @cache
     async def get(self, user_uuid: str) -> Optional[CreditReport]:
         return await self._get(user_uuid)
 
 
 class SyncCreditReportResource(BaseCreditReportResource):
+    @cache
     def get(self, user_uuid: str) -> Optional[CreditReport]:
         return self._client.run(self._get(user_uuid))
