@@ -1,5 +1,5 @@
 from abc import ABC
-from typing import List
+from typing import List, Optional
 
 from pydantic import BaseModel, validate_arguments
 
@@ -13,7 +13,7 @@ PATH = "/users/{user_uuid}/institutions"
 class Institution(BaseModel):
     institution_id: str
     display_name: str
-    currency: Currency
+    currency: Optional[Currency]
     account_types: List[AccountType]
 
 
