@@ -5,6 +5,7 @@ from typing import List, Optional
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 
@@ -102,6 +103,7 @@ class BaseUsersResource(ABC):
 
 
 class AsyncUsersResource(BaseUsersResource):
+    @cache
     async def get(
         self,
         *,
@@ -117,6 +119,7 @@ class AsyncUsersResource(BaseUsersResource):
 
 
 class SyncUsersResource(BaseUsersResource):
+    @cache
     def get(
         self,
         *,
